==> ParaView-v5.1.2.tar.gz: ParaView-v5.1.2/Examples/CustomApplications/MultiServerClient/MultiServerClientMainWindow.h <==
/*=========================================================================

   Program: ParaView
   Module:  MultiServerClientMainWindow.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2. 
   
   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef MultiServerClientMainWindow_h
#define MultiServerClientMainWindow_h

#include <QMainWindow>

class pqServer;
class pqPipelineBrowserWidget;
class QComboBox;

class MultiServerClientMainWindow : public QMainWindow
{
  Q_OBJECT
  typedef QMainWindow Superclass;
public:
  MultiServerClientMainWindow(QWidget* parent = 0, Qt::WindowFlags flags=0);
  ~MultiServerClientMainWindow();

protected slots:
  void addServerInFiltering(pqServer*);
  void applyPipelineFiltering(int);
  void applyPipelineFiltering2(int);

private:
  Q_DISABLE_COPY(MultiServerClientMainWindow);

  pqPipelineBrowserWidget* pipelineBrowser;
  QComboBox* comboBox;
  pqPipelineBrowserWidget* pipelineBrowser2;
  QComboBox* comboBox2;
};
#endif

==> ParaView-v5.2.0.tar.gz: ParaView-v5.2.0/Examples/CustomApplications/MultiServerClient/MultiServerClientMainWindow.h <==
/*=========================================================================

   Program: ParaView
   Module:  MultiServerClientMainWindow.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef MultiServerClientMainWindow_h
#define MultiServerClientMainWindow_h

#include <QMainWindow>

class pqServer;
class pqPipelineBrowserWidget;
class QComboBox;

class MultiServerClientMainWindow : public QMainWindow
{
  Q_OBJECT
  typedef QMainWindow Superclass;

public:
  MultiServerClientMainWindow(QWidget* parent = 0, Qt::WindowFlags flags = 0);
  ~MultiServerClientMainWindow();

protected slots:
  void addServerInFiltering(pqServer*);
  void applyPipelineFiltering(int);
  void applyPipelineFiltering2(int);

private:
  Q_DISABLE_COPY(MultiServerClientMainWindow)

  pqPipelineBrowserWidget* pipelineBrowser;
  QComboBox* comboBox;
  pqPipelineBrowserWidget* pipelineBrowser2;
  QComboBox* comboBox2;
};
#endif
